==> httpmaid-events-0.9.31-sources.jar: de/quantummaid/httpmaid/events/ExternalEventMapping.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.httpmaid.events;

import de.quantummaid.httpmaid.chains.ChainName;
import de.quantummaid.httpmaid.chains.MetaData;
import de.quantummaid.httpmaid.chains.Processor;
import de.quantummaid.httpmaid.events.enriching.EnrichableMap;

import java.util.Map;
import java.util.Optional;

import static de.quantummaid.httpmaid.events.EventModule.EVENT;
import static java.util.Optional.empty;

public interface ExternalEventMapping extends Processor {

    void handle(Map<String, Object> event);

    @Override
    default void apply(final MetaData metaData) {
        final EnrichableMap event = metaData.get(EVENT);
        handle(event.asMap());
    }

    default Optional<ChainName> jumpTarget() {
        return empty();
    }
}

==> httpmaid-events-0.9.48-sources.jar: de/quantummaid/httpmaid/events/ExternalEventMapping.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.httpmaid.events;

import de.quantummaid.httpmaid.chains.ChainName;
import de.quantummaid.httpmaid.chains.MetaData;
import de.quantummaid.httpmaid.chains.Processor;

import java.util.Map;
import java.util.Optional;

import static de.quantummaid.httpmaid.events.EventModule.EVENT;
import static java.util.Optional.empty;

public interface ExternalEventMapping extends Processor {

    void handle(Map<String, Object> event);

    @Override
    default void apply(final MetaData metaData) {
        final Event event = metaData.get(EVENT);
        handle(event.asMap());
    }

    default Optional<ChainName> jumpTarget() {
        return empty();
    }
}
